<?php

/************************************************************
*                     GLOBAL SETTINGS                       *
************************************************************/

function pp_ch_global_settings_form() {
  $vocabularies = taxonomy_get_vocabularies();
  $options = array('--' => t('<none>'));
  foreach ($vocabularies as $vocabulary) {
    $options[$vocabulary->vid] = $vocabulary->name;
  }
  $default = variable_get('pp_ch_channel_vocabulary', '--');
  if (empty($options[$default])) {
    $default = '--';
  }

  $form = array();
  $form['channel_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Vocabulary for channels'),
  );
  
  $form['channel_settings']['pp_ch_channel_vocabulary'] = array(
    '#title' => t('Please select the vocabulary to use as your channel hierarchy'),
    '#type' => 'select',
    '#description' => t('Warning: Changing this value on an existing site may have unexpected consequences.'),
    '#options' => $options,
    '#default_value' => $default,
    '#required' => TRUE,
  );
  $form['#submit'] = array('pp_ch_global_settings_form_submit');

  return system_settings_form($form);
}

function pp_ch_global_settings_form_validate($form, &$form_state) {
  if ($form_state['values']['op'] != t('Reset to defaults') && $form_state['values']['pp_ch_channel_vocabulary'] == '--') {
    form_set_error('pp_ch_channel_vocabulary', t('Please select a vocabulary.'));
  }
}

function pp_ch_global_settings_form_submit($form, &$form_state) {
  // Claim this vocabulary as our own 
  if ($form_state['values']['op'] != t('Reset to defaults')) {
    $vocab = taxonomy_vocabulary_load($form_state['values']['pp_ch_channel_vocabulary']);
    if ($vocab) {
      $vocab->module = 'pp_ch';
      $vocab = (array) $vocab;
      taxonomy_save_vocabulary($vocab);
    }
  }
}


/************************************************************
*                    CHANNEL SETTINGS                       *
************************************************************/

function pp_ch_channels_overview() {
  $vocabulary = variable_get('pp_ch_channel_vocabulary', '--');
  if ($vocabulary == '--') {
    $output = t('You have not selected a channel vocabulary.');
  }
  else {
    module_load_include('inc', 'taxonomy', 'taxonomy.admin');
    $output = drupal_get_form('taxonomy_overview_terms', taxonomy_vocabulary_load($vocabulary));
    drupal_set_title(t('Channels'));
  }
  
  return $output;
}

function pp_ch_add_channel_page() {
  $vocabulary = variable_get('pp_ch_channel_vocabulary', '--');
  if ($vocabulary == '--') {
    $output = t('You have not selected a channel vocabulary.');
  }
  else {
    module_load_include('inc', 'taxonomy', 'taxonomy.admin');
    $output = drupal_get_form('taxonomy_form_term' , taxonomy_vocabulary_load($vocabulary));
  }
  return $output;
}

function pp_ch_channel_settings(&$form, $form_state, $form_id) {
  if (empty($form_state['confirm_delete'])) {
    $channel = pp_ch_load($form['#term']['tid']);
    if (!$channel) {
      // Populate defaults
      $channel = array(
        'editions_enable' => FALSE,
      );
    }
    pp_ch_expand_menu_links($channel);
    
    $form['channel_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Channel settings'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#description' => t(''),
      '#tree' => TRUE,
    );
    $form['channel_settings']['editions_enable'] = array(
      '#type' => 'radios',
      '#title' => t('Channel mode'),
      '#options' => array(
        0 => t('Use a reverse chronological story listing for this channel.'),
        1 => t('Use scheduled editions for this channel.'),
      ),
      '#default_value' => $channel['editions_enable'] ? 1 : 0,
    );
    $form['channel_settings']['old_editions_enable'] = array(
      '#type' => 'value',
      '#value' => $form['channel_settings']['editions_enable']['#default_value'],
    );

    foreach (pp_ch_channel_setting_groups($channel['tid'], $channel['editions_enable']) as $k => $v) {
      if (empty($v['enable']))
        continue;
      
      $form['channel_settings']['s' . $k] = array(
        '#type' => 'fieldset',
        '#title' => $v['label'],
        '#collapsible' => TRUE,
        // '$collapsed' => FALSE
        '#collapsed' => empty($channel['s' . $k]['url']) && empty($channel['s' . $k]['menu_item']['mlid']),
      );

      $form['channel_settings']['s' . $k]['old_path'] = array(
        '#type' => 'value',
        '#value' =>  $channel['s' . $k]['path'],
      );
      $form['channel_settings']['s' . $k]['url'] = array(
        '#type' => 'textfield',
        '#title' => t('URL path'),
        '#description' => t("An optional alternative URL by which this item can be viewed ie. news, news/national or magazines/mymagazine. Use a relative path and don't start nor end with a slash."),
        '#default_value' => $channel['s' . $k]['url'],
      );
      $form['channel_settings']['s' . $k]['old_url'] = array(
        '#type' => 'value',
        '#value' =>  $channel['s' . $k]['url'],
      );

      $form['channel_settings']['s' . $k]['menu_item'] = array(
        '#type' => 'fieldset',
        '#title' => t('Menu settings'),
        '#attributes' => array('class' => 'menu-item-form'),
      );
      $form['channel_settings']['s' . $k]['menu_item']['mlid'] = array(
        '#type' => 'value',
        '#value' => $channel['s' . $k]['menu_item']['mlid'] ? $channel['s' . $k]['menu_item']['mlid'] : 0,
      );

      $form['channel_settings']['s' . $k]['menu_item']['delete'] = array(
        '#type' => 'checkbox',
        '#title' => t('Remove this item from the menu.'),
      );

      $form['channel_settings']['s' . $k]['menu_item']['link_title'] = array(
      '#title' => t('Menu link title'),
      '#type' => 'textfield',
      '#description' => t('The link text corresponding to this item that should appear in the menu. Leave blank if you do not wish to add this item to the menu.'),
      '#default_value' => $channel['s' . $k]['menu_item']['link_title'],
      );

      $form['channel_settings']['s' . $k]['menu_item']['description'] = array(
      '#title' => t('Hover text'),
      '#type' => 'textfield',
      '#description' => t('The description displayed when hovering over the menu item.'),
      '#default_value' => $channel['s' . $k]['menu_item']['options']['attributes']['title'],
      );

      $options = menu_parent_options(menu_get_menus(), $channel['s' . $k]['menu_item']);
      $default = $channel['s' . $k]['menu_item']['menu_name'] .':'. $channel['s' . $k]['menu_item']['plid'];
      if (!isset($options[$default])) {
        $default = 'primary-links:0';
      }

      $form['channel_settings']['s' . $k]['menu_item']['parent'] = array(
        '#title' => t('Parent menu item'),
        '#type' => 'select',
        '#description' => ('The maximum depth for an item and all its children is fixed at 9. Some menu items may not be available as parents if selecting them would exceed this limit.'),
        '#options' => $options,
        '#default_value' => $default,  
        '#attributes' => array('class' => 'menu-title-select'),
      );

      $form['channel_settings']['s' . $k]['menu_item']['weight'] = array(
        '#type' => 'weight',
        '#title' => t('Weight'),
        '#delta' => 50,
        '#default_value' => $channel['s' . $k]['menu_item']['weight'] ? $channel['s' . $k]['menu_item']['weight'] : '0',
        '#description' => t('Optional. In the menu, the heavier items will sink and the lighter items will be positioned nearer the top.'),
      );
    }

    // Title visibility
    $form['channel_settings']['title_visibility'] = array(
      '#type' => 'fieldset',
      '#title' => t('Title visiblity'),
      '#collapsible' => TRUE,
      '#description' => t('These settings control whether the channel name appears as the title on certain channel pages.'),
    );
    $form['channel_settings']['title_visibility']['title_on_channel_page'] = array(
      '#type' => 'checkbox',
      '#title' => t('Show title on channel page'),
      '#description' => t('If ticked, show the title on the !link.<br />This setting only has an effect if the channel is using scheduled editions. If the channel is not using scheduled editions, please ignore this setting.', array('!link' => empty($channel['tid']) ? 'channel page' : l('channel page', 'channel/' . $channel['tid']))),
      '#default_value' => isset($channel['data']['title_on_channel_page']) ? $channel['data']['title_on_channel_page'] : 1,
    );
    $form['channel_settings']['title_visibility']['title_on_listing_page'] = array(
      '#type' => 'checkbox',
      '#title' => t('Show title on story listing page'),
      '#description' => t('If ticked, show the title on the !link.', array('!link' => empty($channel['tid']) ? 'story listing page' : l('story listing page', 'channel/' . $channel['tid'] . '/stories'))),
      '#default_value' => isset($channel['data']['title_on_listing_page']) ? $channel['data']['title_on_listing_page'] : 1,
    );

    $form['advanced']['#weight'] = 1;
    $form['submit']['#weight'] = 2;
    $form['delete']['#weight'] = 3;
  }
  
  $form['#submit'][] = 'pp_ch_channel_settings_submit';  
}

function pp_ch_channel_settings_submit2($form, &$form_state) {
  if ($form_state['values']['delete'] === TRUE) {
    pp_ch_delete($form_state['values']['tid']);
  }
  else if ($form_state['clicked_button']['#value'] == t('Save')) {
    $channel = $form_state['values']['channel_settings'];
    $channel['tid'] = $form_state['values']['tid'];
    $channel['vid'] = $form_state['values']['vid'];

    // Move some values into the 'data' column
    $channel['data'] = array(
      'title_on_channel_page' => $form_state['values']['channel_settings']['title_visibility']['title_on_channel_page'],
      'title_on_listing_page' => $form_state['values']['channel_settings']['title_visibility']['title_on_listing_page'],
    );

    pp_ch_update($channel);
  }
}
