
(function() {
  tinymce.create('tinymce.plugins.PP_Editor_Media', {
    /**
     * Initializes the plugin, this will be executed after the plugin has been created.
     * This call is done before the editor instance has finished it's initialization so use the onInit event
     * of the editor instance to intercept that event.
     *
     * @param {tinymce.Editor} ed Editor instance that the plugin is initialized in.
     * @param {string} url Absolute URL to where the plugin is located.
     */
    init : function(ed, url) {
      var t = this;

      // Register the command so that it can be invoked by using tinyMCE.activeEditor.execCommand();
      ed.addCommand('mcePPEdMedia', function() {
        var elem = $(ed.selection.getNode()).parents('pp_media')[0];
        if (elem) {
          // We have selected an existing pp_media
          nid = $(elem).attr('nid');
          url = Drupal.settings.basePath + '?q=pp_ed/insert/media/insert/' + nid;
          query = '&preset=' + $(elem).attr('preset');

          // deliberate assignment, not conditional equals
          if (title = $(elem).attr('title')) {
            query += '&title=' + title;
          }
          if (caption = $(elem).attr('caption')) {
            query += '&caption=' + caption;
          }
          if (align = $(elem).attr('align')) {
            query += '&align=' + align;
          }
          if (width = $(elem).attr('width')) {
            query += '&width=' + width;
          }
          if (height = $(elem).attr('height')) {
            query += '&height=' + height;
          }
          if (url && query) {
            ed.windowManager.open({
              file : url + query,
              width : 800,
              height : 500,
              scrollbars : 'yes'
            });
          }
        }
        else {
          // No we haven't. New media. 
          ed.windowManager.open({
            file : Drupal.settings.basePath + '?q=pp_ed/insert/media/start',
            width : 800,
            height : 500,
            scrollbars : 'yes'
          });
        }
      });

      // Register the command so that it can be invoked by using tinyMCE.activeEditor.execCommand();
      ed.addCommand('mcePPEdMediaDelete', function() {
        var elem = $(ed.selection.getNode()).parents('pp_media')[0];
        if (elem) {
          ed.dom.remove(elem);
          ed.execCommand('mceRepaint');
        }
      });

      // Register media buttons
      ed.addButton('pp_ed_media', {
        title : 'ProsePoint Media Insert',
        cmd : 'mcePPEdMedia',
        image : url + '/img/media.gif'
      });
      ed.addButton('pp_ed_media_del', {
        title : 'ProsePoint Media Delete',
        cmd : 'mcePPEdMediaDelete',
        image : url + '/img/media_del.gif'
      });

      ed.onNodeChange.add(function(ed, cm, n) {
        // Look for a <pp_img> parent node
        var parent = $(n).parents('pp_media')[0];
        if (parent) {
          cm.setActive('pp_ed_media', true);
          cm.setActive('pp_ed_media_del', true);
          cm.setDisabled('pp_ed_media_del', false);
        } else {
          cm.setActive('pp_ed_media', false);
          cm.setActive('pp_ed_media_del', false);
          cm.setDisabled('pp_ed_media_del', true);
        }
      });
      
      ed.onBeforeSetContent.add(function(ed, o) {
        o.content = t.__to_html(o.content);
      });
      ed.onGetContent.add(function(ed, o) {
        o.content = t.__from_html(o.content);
      });

      /*
      ed.onSetContent.add(function(ed, o) {
        alert('onSetContent: ' + o.content);
      });
      ed.onBeforeGetContent.add(function(ed, o) {
        alert('onBeforeGetContent: ' + o.content);
      });
      ed.onPreProcess.add(function(ed, o) {
        alert('onPreProcess: ' + o.content);
      });
      ed.onPostProcess.add(function(ed, o) {
        if (o.get) {
          alert('onPostProcess: get: ' + o.content);
          // o.content = t.__from_html(o.content);
        }
        else if (o.set)
          alert('onPostProcess: set: ' + o.content);
        else
          alert('onPostProcess: ??');
      });
      */
    },

    onInit : function(ed) {
      ed.controlManager.setDisabled('pp_ed_media_del', TRUE);
    },

    // convert internal notation to html
    __to_html : function(co) {
      // alert('__to_html: input: ' + co);       
      var data = co.replace(/(<pp_media.*?)<\/pp_media *>/gi, function (a, b) {
        var html = $.ajax({url: Drupal.settings.basePath + '?q=pp_ed/render/pp_media' + '&pp_media=' + encodeURIComponent('pp_media in_editor="1"' + b.substring(9,b.length-2)), async: false }).responseText;
        var output = b + html + ' </pp_media>';   // A space prevents tinymce from trying to clean up this tag
        return output;
      });
      // alert('__to_html: output: ' + data);
      return data;
    },

    // convert html to internal notation
    __from_html : function(co) {
      // alert('__from_html: input: ' + co);
      var data = co.replace(/(<pp_media[^>]*>)(.|\n)+?<\/pp_media *>/gi, function (a, b) {
        var result = /<p class="caption">((.|\n)+?)<\/p>/i.exec(a);
        // Move user-editable caption over into pp_media tag
        if (result && result[1]) {
          result = result[1];
          b = b.replace(/caption=".+?"/i, 'caption="' + result + '"');          
        }
        return b + ' </pp_media>';
      });
      // alert('__from_html: output: ' + data);
      return data;
    },

    // convert internal notation to html, but as an already transformed tinymce custom element
    __to_html_for_insert : function(co) {
      // alert('__to_html_for_insert: input: ' + co);       
      var data = co.replace(/(<pp_media(.*?))<\/pp_media *>/gi, function (a, b, c) {
        var html = $.ajax({url: Drupal.settings.basePath + '?q=pp_ed/render/pp_media' + '&pp_media=' + encodeURIComponent('pp_media in_editor="1"' + b.substring(9,b.length-2)), async: false }).responseText;
        var output = '<pp_media' + c + html + ' </pp_media>';   // A space prevents tinymce from trying to clean up this tag
        return output;
      });
      // alert('__to_html_for_insert: output: ' + data);
      return data;
    },


    /**
     * Creates control instances based in the incomming name. This method is normally not
     * needed since the addButton method of the tinymce.Editor class is a more easy way of adding buttons
     * but you sometimes need to create more complex controls like listboxes, split buttons etc then this
     * method can be used to create those.
     *
     * @param {String} n Name of the control to create.
     * @param {tinymce.ControlManager} cm Control manager to use inorder to create new control.
     * @return {tinymce.ui.Control} New control instance or null if no control was created.
     */
    createControl : function(n, cm) {
      return null;
    },

    /**
     * Returns information about the plugin as a name/value array.
     * The current keys are longname, author, authorurl, infourl and version.
     *
     * @return {Object} Name/value array containing information about the plugin.
     */
    getInfo : function() {
      return {
        longname : 'ProsePoint Editor Media Insert',
        author : 'Beng Tan',
        authorurl : 'http://thinkleft.com.au',
        infourl : 'http://www.prosepoint.org',
        version : "0.03"
      };
    }
  });

  // Register plugin
  tinymce.PluginManager.add('pp_ed_media', tinymce.plugins.PP_Editor_Media);
})();
